@@ -16,9 +16,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 ##
+
+import sys
+
 import marshmallow_dataclass
 
 from aceql._private.file_util import FileUtil
+from aceql._private.parms import Parms
 from aceql._private.user_login_store import UserLoginStore
 from aceql._private.jdbc_database_meta_data_dto import JdbcDatabaseMetaDataDto
 from aceql._private.table_dto import TableDto
@@ -36,7 +40,6 @@ from aceql._private.row_counter import RowCounter
 from aceql._private.stream_result_analyzer import StreamResultAnalyzer
 from aceql._private.version_values import VersionValues
 
-
 class AceQLHttpApi(object):
     """ AceQL HTTP wrapper for all apis. Takes care of all
     HTTP calls and operations."""
@@ -333,6 +336,16 @@ class AceQLHttpApi(object):
     def get_client_version():
         return VersionValues.NAME + " - " + VersionValues.VERSION + " - " + VersionValues.DATE
 
+    # *
+    # * Gets the SDK version + Python version
+    # *
+    # * @
+    # * if any Exception occurs
+    #
+    @staticmethod
+    def get_client_version_full():
+        return AceQLHttpApi.get_client_version() + " - " + sys.version
+
     # *
     # * Calls /close API
     # *
@@ -475,18 +488,12 @@ class AceQLHttpApi(object):
 
             action = "execute_update"
 
-            if sql is None:
-                raise TypeError("sql is null!")
-            if is_prepared_statement is None:
-                raise TypeError("isPreparedStatement is null!")
+            self.check_values(is_prepared_statement, sql)
 
             dict_params = {}
             dict_params["sql"] = sql
 
-            if str(is_prepared_statement) == 'True':
-                dict_params["prepared_statement"] = "true"
-            else:
-                dict_params["prepared_statement"] = "false"
+            self.set_is_prepared_statement(dict_params, is_prepared_statement)
 
             url_withaction = self._url + action
 
@@ -561,18 +568,10 @@ class AceQLHttpApi(object):
 
             action = "execute_query"
 
-            if sql is None:
-                raise TypeError("sql is null!")
-            if isPreparedStatement is None:
-                raise TypeError("isPreparedStatement is null!")
+            self.check_values(isPreparedStatement, sql)
 
-            dict_params = {}
-            dict_params["sql"] = sql
-
-            if str(isPreparedStatement) == 'True':
-                dict_params["prepared_statement"] = "true"
-            else:
-                dict_params["prepared_statement"] = "false"
+            dict_params = {"sql": sql}
+            self.set_is_prepared_statement(dict_params, isPreparedStatement)
 
             url_withaction = self._url + action
 
@@ -585,16 +584,7 @@ class AceQLHttpApi(object):
 
                 dict_params.update(statementParameters)
 
-            if self._gzipResult:
-                dict_params["gzip_result"] = "true"
-            if self._prettyPrinting:
-                dict_params["pretty_printing"] = "true"
-
-            # Force pretty printing to True because parser needs it
-            dict_params["pretty_printing"] = "true"
-
-            # We need the types
-            dict_params["column_types"] = "true"
+            self.update_dict_params(dict_params)
 
             AceQLDebug.debug("dictParams 2: " + str(dict_params))
 
@@ -618,31 +608,7 @@ class AceQLHttpApi(object):
 
             AceQLDebug.debug("after open filename")
 
-            file_out = None
-
-            if self.is_gzip_result():
-                file_out = filename[0: len(filename) - 4] + ".ungzipped.txt"
-                FileUtil.decompress(filename, file_out)
-                from aceql import Parms
-                if Parms.DELETE_FILES:
-                    os.remove(filename)
-            else:
-                file_out = filename
-
-            AceQLDebug.debug("Before StreamResultAnalyzer")
-
-            result_analyzer = StreamResultAnalyzer(file_out, self.__http_status_code)
-            if not result_analyzer.is_status_ok():
-                if Parms.DELETE_FILES:
-                    os.remove(filename)
-                raise Error(result_analyzer.get_error_message(),
-                            result_analyzer.get_error_type(), None, None, self.__http_status_code)
-
-            row_counter = RowCounter(file_out)
-            row_count = row_counter.count()
-
-            result_set_info = ResultSetInfo(file_out, row_count)
-            AceQLDebug.debug("Before resultSetInfo")
+            result_set_info = self.treat_result(filename)
 
             return result_set_info
 
@@ -652,6 +618,51 @@ class AceQLHttpApi(object):
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
 
+    def treat_result(self, filename):
+        file_out = None
+        if self.is_gzip_result():
+            file_out = filename[0: len(filename) - 4] + ".ungzipped.txt"
+            FileUtil.decompress(filename, file_out)
+            if Parms.DELETE_FILES:
+                os.remove(filename)
+        else:
+            file_out = filename
+        AceQLDebug.debug("Before StreamResultAnalyzer")
+        result_analyzer = StreamResultAnalyzer(file_out, self.__http_status_code)
+        if not result_analyzer.is_status_ok():
+            if Parms.DELETE_FILES:
+                os.remove(filename)
+            raise Error(result_analyzer.get_error_message(),
+                        result_analyzer.get_error_type(), None, None, self.__http_status_code)
+        row_counter = RowCounter(file_out)
+        row_count = row_counter.count()
+        result_set_info = ResultSetInfo(file_out, row_count)
+        AceQLDebug.debug("Before resultSetInfo")
+        return result_set_info
+
+    def update_dict_params(self, dict_params):
+        if self._gzipResult:
+            dict_params["gzip_result"] = "true"
+        if self._prettyPrinting:
+            dict_params["pretty_printing"] = "true"
+        # Force pretty printing to True because parser needs it
+        dict_params["pretty_printing"] = "true"
+        # We need the types
+        dict_params["column_types"] = "true"
+
+    def check_values(self, is_prepared_statement, sql):
+        if sql is None:
+            raise TypeError("sql is null!")
+        if is_prepared_statement is None:
+            raise TypeError("isPreparedStatement is null!")
+
+    @staticmethod
+    def set_is_prepared_statement(dict_params, is_prepared_statement):
+        if str(is_prepared_statement) == 'True':
+            dict_params["prepared_statement"] = "true"
+        else:
+            dict_params["prepared_statement"] = "false"
+
     def get_blob_stream(self, blob_id):
         """ returns a BLOB stream as a Requests response """
         try:
